#!/bin/bash

# File root
root="/run/media/sylvain/LIVE/getPackages"

# Make directories
echo "Reset directories ..."
rm -rf "$root/yum"
mkdir "$root/yum"
mkdir "$root/yum/cache"
mkdir "$root/yum/persist"

# Up-to-date configuration file (root)
echo "Update local configuration file ..."
echo "
[main]
cachedir=$root/yum/cache
persistdir=$root/yum/persist
logfile=$root/yum/yum.log
metadata_expire=never
keepcache=1
debuglevel=2
exactarch=1
obsoletes=1
gpgcheck=1
plugins=1
installonly_limit=3
max_connections=1

[cache.fedora.i386]
name=Fedora 18 - i386
failovermethod=priority
baseurl=file://$root/fedora.mirrors.ovh.net/linux/releases/18/Everything/i386/os
enabled=1
gpgcheck=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-fedora-i386

[cache.fedora.x86_64]
name=Fedora 18 - x86_64
failovermethod=priority
baseurl=file://$root/fedora.mirrors.ovh.net/linux/releases/18/Everything/x86_64/os
enabled=1
gpgcheck=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-fedora-x86_64

[cache.updates.i386]
name=Fedora 18 - i386 - Updates
failovermethod=priority
baseurl=file://$root/fedora.mirrors.ovh.net/linux/updates/18/i386
enabled=1
gpgcheck=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-fedora-i386

[cache.updates.x86_64]
name=Fedora 18 - x86_64 - Updates
failovermethod=priority
baseurl=file://$root/fedora.mirrors.ovh.net/linux/updates/18/x86_64
enabled=1
gpgcheck=1
gpgkey=file:///etc/pki/rpm-gpg/RPM-GPG-KEY-fedora-x86_64
" > "$root/yum/yum.conf"

# Build cache
echo "Build yum cache :"
yum --config="$root/yum/yum.conf" --disablerepo=* --enablerepo=cache.* makecache

# Clear repository data
echo "Clear downloaded data ..."
rm -rf "$root/fedora.mirrors.ovh.net"

# Build aliases
echo "Aliases (should be copied in ~/.bashrc) :"

alias yum32="yum --config=\"$root/yum/yum.conf\" --disablerepo=* --enablerepo=cache.*.i386"
echo "alias yum32=\'yum --config=\"$root/yum/yum.conf\" --disablerepo=* --enablerepo=cache.*.i386\'"

alias yum64="yum --config=\"$root/yum/yum.conf\" --disablerepo=* --enablerepo=cache.*.x86_64"
echo "alias yum64=\'yum --config=\"$root/yum/yum.conf\" --disablerepo=* --enablerepo=cache.*.x86_64\'"

